@@ -37,6 +37,7 @@ if typing.TYPE_CHECKING:
         ListFieldMethod,
         ParserMethod,
         Subcast,
+        TimeDeltaFieldMethod,
     )
 
     try:
@@ -44,7 +45,7 @@ if typing.TYPE_CHECKING:
     except ImportError:
         pass
 
-__all__ = ["Env", "EnvError", "ValidationError", "env"]
+__all__ = ["Env", "EnvError", "FileAwareEnv", "ValidationError", "env"]
 
 _T = typing.TypeVar("_T")
 _StrType = str
@@ -134,7 +135,7 @@ def _field2method(
             self._errors[parsed_key].extend(error.messages)
         else:
             self._values[parsed_key] = value
-        return typing.cast("typing.Optional[_T]", value)
+        return typing.cast("_T | None", value)
 
     method.__name__ = method_name
     return method
@@ -181,7 +182,7 @@ def _func2method(func: typing.Callable[..., _T], method_name: str) -> typing.Any
             self._errors[parsed_key].extend(messages)
         else:
             self._values[parsed_key] = value
-        return typing.cast("typing.Optional[_T]", value)
+        return typing.cast("_T | None", value)
 
     method.__name__ = method_name
     return method
@@ -267,7 +268,7 @@ def _preprocess_json(value: str | typing.Mapping | list, **kwargs):
 
 def _dj_db_url_parser(value: str, **kwargs) -> DBConfig:
     try:
-        import dj_database_url
+        import dj_database_url  # noqa: PLC0415
     except ImportError as error:
         raise RuntimeError(
             "The dj_db_url parser requires the dj-database-url package. "
@@ -281,7 +282,7 @@ def _dj_db_url_parser(value: str, **kwargs) -> DBConfig:
 
 def _dj_email_url_parser(value: str, **kwargs) -> dict:
     try:
-        import dj_email_url
+        import dj_email_url  # noqa: PLC0415
     except ImportError as error:
         raise RuntimeError(
             "The dj_email_url parser requires the dj-email-url package. "
@@ -295,7 +296,7 @@ def _dj_email_url_parser(value: str, **kwargs) -> dict:
 
 def _dj_cache_url_parser(value: str, **kwargs) -> dict:
     try:
-        import django_cache_url
+        import django_cache_url  # noqa: PLC0415
     except ImportError as error:
         raise RuntimeError(
             "The dj_cache_url parser requires the django-cache-url package. "
@@ -345,7 +346,7 @@ class Env:
     datetime: FieldMethod[dt.datetime] = _field2method(ma.fields.DateTime, "datetime")
     date: FieldMethod[dt.date] = _field2method(ma.fields.Date, "date")
     time: FieldMethod[dt.time] = _field2method(ma.fields.Time, "time")
-    timedelta: FieldMethod[dt.timedelta] = _field2method(fields.TimeDelta, "timedelta")
+    timedelta: TimeDeltaFieldMethod = _field2method(fields.TimeDelta, "timedelta")
     path: FieldMethod[Path] = _field2method(fields.Path, "path")
     log_level: FieldMethod[_IntType] = _field2method(fields.LogLevel, "log_level")
 
@@ -520,7 +521,7 @@ class Env:
         to get a proxy env key.
         """
         env_key = self._get_key(key, omit_prefix=proxied)
-        value = os.environ.get(env_key, default)
+        value = self._get_value(env_key, default)
         if hasattr(value, "strip"):
             expand_match = self.expand_vars and _EXPANDED_VAR_PATTERN.match(value)
             if expand_match:  # Full match expand_vars - special case keep default
@@ -569,6 +570,39 @@ class Env:
     def _get_key(self, key: _StrType, *, omit_prefix: _BoolType = False) -> _StrType:
         return self._prefix + key if self._prefix and not omit_prefix else key
 
+    def _get_value(self, env_key: _StrType, default: typing.Any) -> typing.Any:
+        return os.environ.get(env_key, default)
+
+
+class FileAwareEnv(Env):
+    """An environment variable reader that supports reading values from files."""
+
+    def __init__(
+        self,
+        *,
+        file_suffix: _StrType = "_FILE",
+        eager: _BoolType = True,
+        expand_vars: _BoolType = False,
+        prefix: _StrType | None = None,
+        strip_whitespace: _BoolType = False,
+    ):
+        self.file_suffix: _StrType = file_suffix
+        self.strip_whitespace: _BoolType = strip_whitespace
+        super().__init__(eager=eager, expand_vars=expand_vars, prefix=prefix)
+
+    def _get_value(self, env_key: _StrType, default: typing.Any) -> typing.Any:
+        """Return the contents of the file referenced in key <env_key>_FILE, if present."""
+        file_key = f"{env_key}{self.file_suffix}"
+        if file_path := os.environ.get(file_key, None):
+            try:
+                value: _StrType = Path(file_path).read_text()
+                return value.strip() if self.strip_whitespace else value
+            except (FileNotFoundError, IsADirectoryError, PermissionError) as err:
+                raise ValueError(
+                    f"The value of {file_key} must be a readable file path."
+                ) from err
+        return super()._get_value(env_key, default)
+
 
 # Singleton instance, for convenience
 env = Env()
